Название потом придумаю
=======================

The Python SQL Toolkit for automatic database migration in raw sql queries

# Introduction


# Documentation

# Installation / Requirements


## Linux / Mac ::

```bash
$ cd simple
$ virtualenv env
$ source env/bin/activate
```


## Windows ::

$ cd simple
$ virtualenv env
$ env/Scripts/activate.ps1

Getting Help / Development / Bug reporting
------------------------------------------

Code of Conduct
---------------


License
-------
